From 3498f7f39f32e82d4ce4178f708b56e29aadcea0 Mon Sep 17 00:00:00 2001
From: tbrehm <t.brehm@ispconfig.org>
Date: Thu, 20 Oct 2011 06:23:56 -0400
Subject: [PATCH] - Updated italian language files. - Fixed a warning in apache plugin.

---
 interface/web/admin/language_edit.php |   31 ++++++++++++++++++++-----------
 1 files changed, 20 insertions(+), 11 deletions(-)

diff --git a/interface/web/admin/language_edit.php b/interface/web/admin/language_edit.php
index 6329339..f16ea68 100644
--- a/interface/web/admin/language_edit.php
+++ b/interface/web/admin/language_edit.php
@@ -30,14 +30,12 @@
 require_once('../../lib/config.inc.php');
 require_once('../../lib/app.inc.php');
 
-// Checking permissions for the module
-if(!stristr($_SESSION['s']['user']['modules'],'admin')) {
-	header('Location: ../index.php');
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('admin');
 
 //* This is only allowed for administrators
 if(!$app->auth->is_admin()) die('only allowed for administrators.');
+if($conf['demo_mode'] == true) $app->error('This function is disabled in demo mode.');
 
 $app->uses('tpl');
 
@@ -59,19 +57,30 @@
 	$file_content = "<?php\n";
 	foreach($_POST['records'] as $key => $val) {
 		$val = stripslashes($val);
-		$val = str_replace("'",'',$val);
-		$val = str_replace('"','',$val);
-		$file_content .= '$wb['."'$key'".'] = '."'$val';\n";
+		$val = str_replace('"','\"',$val);
+		$val = str_replace('$','',$val);
+		$file_content .= '$wb['."'$key'".'] = "'.$val.'";'."\n";
 		$msg = 'File saved.';
 	}
 	$file_content .= "?>\n";
-	file_put_contents(ISPC_WEB_PATH."/$module/lib/lang/$lang_file" ,$file_content);
+	if($module == 'global') {
+		file_put_contents(ISPC_LIB_PATH."/lang/$lang_file" ,$file_content);
+	} else {
+		file_put_contents(ISPC_WEB_PATH."/$module/lib/lang/$lang_file" ,$file_content);
+	}
 }
 
 
 $app->tpl->setVar(array('module' => $module,'lang_file' => $lang_file, 'lang' => $lang, 'msg' => $msg));
 
-include(ISPC_WEB_PATH."/$module/lib/lang/$lang_file");
+if($module == 'global') {
+	include(ISPC_LIB_PATH."/lang/$lang_file");
+	$file_path = ISPC_LIB_PATH."/lang/$lang_file";
+} else {
+	include(ISPC_WEB_PATH."/$module/lib/lang/$lang_file");
+	$file_path = ISPC_WEB_PATH."/$module/lib/lang/$lang_file";
+}
+$app->tpl->setVar("file_path", $file_path);
 
 $keyword_list = array();
 if(isset($wb) && is_array($wb)) {
@@ -93,4 +102,4 @@
 $app->tpl->pparse();
 
 
-?>
\ No newline at end of file
+?>

--
Gitblit v1.9.1